/******************** (C) COPYRIGHT 2007 STMicroelectronics ********************
* File Name          : stm32f10x_usart.h
* Author             : MCD Application Team
* Date First Issued  : 09/29/2006
* Description        : This file contains all the functions prototypes for the
*                      USART firmware library.
********************************************************************************
* History:
* 02/05/2007: V0.1
* 09/29/2006: V0.01
********************************************************************************
* THE PRESENT SOFTWARE WHICH IS FOR GUIDANCE ONLY AIMS AT PROVIDING CUSTOMERS
* WITH CODING INFORMATION REGARDING THEIR PRODUCTS IN ORDER FOR THEM TO SAVE TIME.
* AS A RESULT, STMICROELECTRONICS SHALL NOT BE HELD LIABLE FOR ANY DIRECT,
* INDIRECT OR CONSEQUENTIAL DAMAGES WITH RESPECT TO ANY CLAIMS ARISING FROM THE
* CONTENT OF SUCH SOFTWARE AND/OR THE USE MADE BY CUSTOMERS OF THE CODING
* INFORMATION CONTAINED HEREIN IN CONNECTION WITH THEIR PRODUCTS.
*******************************************************************************/

/* Define to prevent recursive inclusion -------------------------------------*/
#ifndef __STM32F10x_USART_H
#define __STM32F10x_USART_H

/* Includes ------------------------------------------------------------------*/
#include "stm32f10x_map.h"

/* Exported types ------------------------------------------------------------*/
/* UART Init Structure definition */
typedef struct
{
  u32 USART_BaudRate;
  u16 USART_WordLength;
  u16 USART_StopBits;
  u16 USART_Parity;
  u16 USART_HardwareFlowControl;
  u16 USART_Mode;
  u16 USART_Clock;
  u16 USART_CPOL;
  u16 USART_CPHA;
  u16 USART_LastBit;
} USART_InitTypeDef;

/* Exported constants --------------------------------------------------------*/
/* USART Data Length */
#define USART_WordLength_8D                  ((u16)0x0000) /* 8 bits Data */
#define USART_WordLength_9D                  ((u16)0x1000) /* 9 bits Data */

/* USART Stop Bits */
#define USART_StopBits_1                     ((u16)0x0000) /* One stop bit is
                                              transmitted at the end of frame */
#define USART_StopBits_0_5                   ((u16)0x1000) /* Half bit stop bits are
                                              transmitted at the end of frame */
#define USART_StopBits_2                     ((u16)0x2000) /* Tow stop bits are
                                              transmitted at the end of frame */
#define USART_StopBits_1_5                   ((u16)0x3000) /* One and half stop bits
                                              are transmitted at the end of
                                              frame */
/* USART Parity */
#define USART_Parity_No                      ((u16)0x0000) /* Parity Disable */
#define USART_Parity_Even                    ((u16)0x0400) /* Even Parity */
#define USART_Parity_Odd                     ((u16)0x0600) /* Odd Parity */

/* USART Hardware Flow Control */
#define USART_HardwareFlowControl_None       ((u16)0x0000) /* HFC Disable */
#define USART_HardwareFlowControl_RTS        ((u16)0x0100) /* RTS Enable */
#define USART_HardwareFlowControl_CTS        ((u16)0x0200) /* CTS Enable */
#define USART_HardwareFlowControl_RTS_CTS    ((u16)0x0300) /* CTS and RTS Enable */

/* USART Mode */
#define USART_Mode_Rx                        ((u16)0x0004) /* USART Rx Enabled */
#define USART_Mode_Tx                        ((u16)0x0008) /* USART Tx Enabled */

/* USART Clock */
#define USART_Clock_Disable                  ((u16)0x0000) /* USART Clock disabled */
#define USART_Clock_Enable                   ((u16)0x0800) /* USART Clock enabled */

/* USART Clock Polarity */
#define USART_CPOL_Low                       ((u16)0x0000) /* Clock is active low */
#define USART_CPOL_High                      ((u16)0x0400) /* Clock is active high */

/* USART Clock Phase */
#define USART_CPHA_1Edge                     ((u16)0x0000) /* Data  is  captured on
                                                              the fisrt edge */
#define USART_CPHA_2Edge                     ((u16)0x0200) /* Data  is  captured on
                                                             second edge */                                                
/* USART Last Bit */
#define USART_LastBit_Disable                ((u16)0x0000) /* The clock pulse of 
                                                              the last data bit 
                                                              is not output to 
                                                              the SCLK pin */                                                       
#define USART_LastBit_Enable                 ((u16)0x0100) /* The clock pulse of 
                                                              the last data bit 
                                                              is output to the 
                                                              SCLK pin */                                                       
/* USART Interrupt definition */
#define USART_IT_PE                          ((u16)0x0028) /* Parity Error interrupt */
#define USART_IT_TXE                         ((u16)0x0727) /* Transmit interrupt */
#define USART_IT_TC                          ((u16)0x0626) /* Transmission Complete interrupt */
#define USART_IT_RXNE                        ((u16)0x0525) /* Receive interrupt */
#define USART_IT_IDLE                        ((u16)0x0424) /* IDLE line interrupt */
#define USART_IT_LBD                         ((u16)0x0846) /* LIN break detection interrupt */
#define USART_IT_CTS                         ((u16)0x096A) /* CTS interrupt */
#define USART_IT_ERR                         ((u16)0x0060) /* Error interrupt */
#define USART_IT_ORE                         ((u16)0x0360) /* Overrun Error interrupt */
#define USART_IT_NE                          ((u16)0x0260) /* Noise Error interrupt */
#define USART_IT_FE                          ((u16)0x0160) /* Frame Error interrupt */

/* USART DMA Requests */
#define USART_DMAReq_Tx                      ((u16)0x0080) /* Transmit DMA request */
#define USART_DMAReq_Rx                      ((u16)0x0040) /* Receive DMA request */

/* USART WakeUp methods */
#define USART_WakeUp_IdleLine                ((u16)0x0000) /* IDLE line WakeUp */
#define USART_WakeUp_AddressMark             ((u16)0x0800) /* Address Mark WakeUp */

/* USART LIN Break Detection Length */
#define USART_LINBreakDetectionLength10      ((u16)0x0000) /* 10 bit break detection */
#define USART_LINBreakDetectionLength11      ((u16)0x0020) /* 11 bit break detection */

/* USART IrDA Low Power */
#define USART_IrDAMode_LowPower              ((u16)0x0004) /* IrDA low Power mode*/
#define USART_IrDAMode_Normal                ((u16)0x0000) /* IrDA normal mode */

/* USART Flags */
#define USART_FLAG_CTS                       ((u16)0x0200) /* CTS flag */
#define USART_FLAG_LBD                       ((u16)0x0100) /* LIN Break detection flag */
#define USART_FLAG_TXE                       ((u16)0x0080) /* Transmit data register empty flag */
#define USART_FLAG_TC                        ((u16)0x0040) /* Transmission complete flag */
#define USART_FLAG_RXNE                      ((u16)0x0020) /* Read data register Not empty flag */
#define USART_FLAG_IDLE                      ((u16)0x0010) /* Idle line detected */
#define USART_FLAG_ORE                       ((u16)0x0008) /* Overrun Error flag */
#define USART_FLAG_NE                        ((u16)0x0004) /* Noise Error flag */
#define USART_FLAG_FE                        ((u16)0x0002) /* Framing Error flag */
#define USART_FLAG_PE                        ((u16)0x0001) /* Parity Error flag */


/* Exported macro ------------------------------------------------------------*/
/* Exported functions ------------------------------------------------------- */
void USART_DeInit(USART_TypeDef* USARTx);
void USART_Init(USART_TypeDef* USARTx, USART_InitTypeDef* USART_InitStruct);
void USART_StructInit(USART_InitTypeDef* USART_InitStruct);
void USART_Cmd(USART_TypeDef* USARTx, FunctionalState NewState);
void USART_ITConfig(USART_TypeDef* USARTx, u16 USART_IT, FunctionalState NewState);
void USART_DMACmd(USART_TypeDef* USARTx, u16 USART_DMAReq, FunctionalState NewState);
void USART_SetAddress(USART_TypeDef* USARTx, u8 USART_Address);
void USART_WakeUpConfig(USART_TypeDef* USARTx, u16 USART_WakeUp);
void USART_ReceiverWakeUpCmd(USART_TypeDef* USARTx, FunctionalState NewState);
void USART_LINBreakDetectionConfig(USART_TypeDef* USARTx, u16 USART_LINBreakDetectionLength);
void USART_LINCmd(USART_TypeDef* USARTx, FunctionalState NewState);
void USART_SendData(USART_TypeDef* USARTx, u16 Data);
u16 USART_ReceiveData(USART_TypeDef* USARTx);
void USART_SendBreak(USART_TypeDef* USARTx);
void USART_SetGuardTime(USART_TypeDef* USARTx, u8 USART_GuardTime);
void USART_SetPrescaler(USART_TypeDef* USARTx, u8 USART_Prescaler);
void USART_SmartCardCmd(USART_TypeDef* USARTx, FunctionalState NewState);
void USART_SmartCardNACKCmd(USART_TypeDef* USARTx, FunctionalState NewState);
void USART_HalfDuplexCmd(USART_TypeDef* USARTx, FunctionalState NewState);
void USART_IrDAConfig(USART_TypeDef* USARTx, u16 USART_IrDAMode);
void USART_IrDACmd(USART_TypeDef* USARTx, FunctionalState NewState);
FlagStatus USART_GetFlagStatus(USART_TypeDef* USARTx, u16 USART_FLAG);
void USART_ClearFlag(USART_TypeDef* USARTx, u16 USART_FLAG);
ITStatus USART_GetITStatus(USART_TypeDef* USARTx, u16 USART_IT);
void USART_ClearITPendingBit(USART_TypeDef* USARTx, u16 USART_IT);

#endif /* __STM32F10x_USART_H */

/******************* (C) COPYRIGHT 2007 STMicroelectronics *****END OF FILE****/
